@@ -108,6 +108,8 @@ build_nomnoml_code <- function(
     "#.repeat: visual=rhomb fill=#fce4d6 align=center\n",
     "#.while: visual=rhomb fill=#fff2cc align=center\n",
     "#.standard: visual=class fill=#ededed align=left\n",
+    "#.standardg: visual=class fill=#70ad47 align=left\n",
+    "#.standardr: visual=class fill=#ed7d31 align=left\n",
     "#.commented: visual=class fill=#ededed\n",
     "#.header: visual=roundrect fill=#d9e1f2 align=left\n",
     "#.return: visual=end fill=#70ad47  empty\n",
